@@ -1,13 +1,13 @@
 use 5.008001;
 use utf8;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 ###########################################################################
 ###########################################################################
 
 { package Set::Relation; # role
-    our $VERSION = '0.013000';
+    our $VERSION = '0.013001';
     $VERSION = eval $VERSION;
 } # role Set::Relation
 
@@ -15,7 +15,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Set::Relation::Mutable; # role
-    our $VERSION = '0.013000';
+    our $VERSION = '0.013001';
     $VERSION = eval $VERSION;
     # with Set::Relation
 } # role Set::Relation::Mutable
@@ -37,7 +37,7 @@ Relation data type for Perl
 
 =head1 VERSION
 
-This document describes Set::Relation version 0.13.0 for Perl 5.
+This document describes Set::Relation version 0.13.1 for Perl 5.
 
 =head1 SYNOPSIS
 
@@ -1788,7 +1788,7 @@ Darren Duncan (C<darren@DarrenDuncan.net>)
 
 =head1 LICENSE AND COPYRIGHT
 
-Set::Relation is Copyright © 2006-2015, Muldis Data Systems, Inc.
+Set::Relation is Copyright © 2006-2016, Muldis Data Systems, Inc.
 
 L<http://www.muldis.com/>
 
